import time
import pandas as pd
import numpy as np
import math

start = time.time()

# 0-1- Basic epidemic variables assumed as the model inputs
C = int(7)       # Incubation Period (5-15)
W = int(1)       # Sub-Clinical Infectious Period  (1-5)
F_inf = 0.545    # RNA copy emission rate of asymptomatic to symptomatic infected individuals
E_option = 1     # Emission options based on either [1] Liu et al. (2020-Nature) or [3] Chia et al. (2020-preprint)[3] 1:1 scenario
H_option = 'S'   # Close distance interaction options ([S]tandard and [E]xtended)

# 0-2- Estimating the modes of transmission f RNA copies (only for acceptable scenarios)
T_mode = 1     # All transmission pathways [1], Long-range inhalable particles and fomite only [0]

# 0-3- Basic important variables for controlling the code
R0_cases = int(6)
ID_cases = int(3)
N_remove = int(7)
N_remain = 3711 * 1800 / 523
if H_option == 'E':
    H_close_cab = 16
    H_close_com = 0
else:
    H_close_cab = 8
    H_close_com = 0

# 1- Calibration period: Index case only from January 20th to Februay 8th (maximum incubation period + 5 days: 20 days)
# 1-1- Inserting the input data
T_cab = 9/24                       # Range (+/- 25%)
if H_close_cab < 9:
    T_close_cab = H_close_cab / 24
else:
    T_close_cab = 9 / 24
T_com = 1 - T_cab
T_close_com = H_close_com / 24
T_act_cab = T_cab - T_close_cab                  # Range (+/- 25%)
T_act_com = T_com - T_close_com
T_ser = 15/(24*60)
if E_option == 1:
    E_aer = 315                        # Range (49-1098) [#/hr/person]
    E_drp = 1152                       # Range (496 - 1808) [#/hr/person]
elif E_option == 2:
    E_aer = 1455461                    # [#/hr/person]
    E_drp = 610512                     # [#/hr/person]
elif E_option == 3:
    E_aer = 2065973/2                  # [#/hr/person]
    E_drp = 2065973/2                  # [#/hr/person]
else:
    E_aer = 'TBD'
    E_drp = 'TBD'
N_inf = 1
N_cab_inf = 1
N_sus_cab = 0
N_sus_com = 523+2666
N_bre = 15*60                      # Range (12*60 - 18*60) [#/hr]
A_mm = ((2*2.76*1.38)+(2*1.13*1.13)+(2*2))/10000           # Range (+/- 25%) [m2]
A_dir_pre = 3*(3**0.5)             # [m2]
A_dir_inj = 3.1415*(1.5**2)/3      # [m2]
A_cab = 22                         # [m2]
A_com_ind = 18000                  # [m2]
A_com_all = 18000 + 17000 + 3700   # [m2]
P_close_cab = T_close_cab + (T_act_cab * A_dir_pre / A_cab)
P_long_cab = T_cab - P_close_cab
P_close_com = T_close_com + (T_act_com * A_dir_pre / A_com_all)
P_long_com = T_com - P_close_com
R_mask = 0
F_cover = 0
K_hvac_cab = 9                     # Range (+/- 25%) [1/hr]
K_hvac_com = 12                    # Range (+/- 25%) [1/hr]
P_inter = 0.05                     # Range (+/- 25%)
K_dep = 0.636                      # Range (0.126 - 1.053) [1/hr]
I_inh = 15.7                       # Range (+/- 10%) [m3/day]
V_cab = A_cab * 2.5                # [m3]
V_com = A_com_ind * 4              # [m3]
T_hl_sur = 6                       # Range (5.0 - 7.0) [hr]
T_hl_air = 1                       # Range (0.5 - 2.0) [hr]
K_inc_hnd = 0.8                    # Test (8.0 to check the impact) [1/hr]
E_sur_hnd = 0.1865                 # Range (0.003 - 0.37)
E_hnd_sur = 0.155                  # Range (0.14 - 0.17)
E_hnd_mm = 0.34
K_hnd_sur = 1.5 * 60               # Range (+/- 0.34*60) [1/hr]
K_hnd_fac = 15.7                   # Range (+/- 11.3) [1/hr]
A_palm = 0.014242                  # Range (+/- 5%) [m2]
P_hnd_wash = 0.70
E_hnd_wash = 0.725
R_disinf = 0
K_recir_cab = 0                    # [1/hr]
K_recir_com = 0                    # [1/hr]
R_air_flt = 0.999
V_bre = I_inh / (24 * N_bre)       # [m3]
V_cone = 3.1415 * (1.5**3) / 9                # [m3]
P_sym_tot = (634 - 320) / 634          # Based on Mizumoto et al. 2020, data until 20 February

# 1-2- Generating the RNA Emission per Cough Matrix (ER)
ER = np.zeros((1, 12))
ER[0, 0] = T_cab * (E_aer / N_bre)
ER[0, 1] = T_com * N_inf * (E_aer / N_bre) * (1 - R_mask)
ER[0, 2] = T_cab * (E_drp / N_bre)
ER[0, 3] = T_com * N_inf * (E_drp / N_bre) * (1 - R_mask)
if T_mode == 1:
    ER[0, 4] = (E_drp / N_bre) * P_close_cab * (A_palm / A_dir_inj)
    ER[0, 5] = (E_drp / N_bre) * P_close_cab * (A_mm / A_dir_inj)
    ER[0, 6] = (E_aer / N_bre) * P_close_cab * (V_bre / V_cone)
    ER[0, 7] = N_inf * (E_drp / N_bre) * P_close_com * (A_palm / A_dir_inj) * (1 - R_mask) * (1 - F_cover)
    ER[0, 8] = N_inf * (E_drp / N_bre) * P_close_com * (A_mm / A_dir_inj) * (1 - R_mask) * (1 - F_cover)
    ER[0, 9] = N_inf * (E_aer / N_bre) * P_close_com * (V_bre / V_cone) * ((1 - R_mask)**2)

# 1-3- Generating Markov Chain Matrix
DF_TR = pd.DataFrame(np.zeros((12, 12)))
DF_TR.iloc[0, 1] = K_hvac_cab * P_inter
DF_TR.iloc[0, 2] = K_dep
DF_TR.iloc[0, 6] = P_long_cab * (I_inh / 24) / V_cab
DF_TR.iloc[0, 9] = (N_cab_inf / N_remain) * T_ser * (I_inh / (24 * V_cab)) * (1 - R_mask)
DF_TR.iloc[0, 10] = K_hvac_cab
DF_TR.iloc[0, 11] = np.log(2) / T_hl_air
DF_TR.iloc[1, 3] = K_dep
DF_TR.iloc[1, 6] = (P_long_com / 2) * (I_inh / (24 * V_com)) * (1 - R_mask)
DF_TR.iloc[1, 9] = (P_long_com / 2) * (I_inh / (24 * V_com)) * (1 - R_mask)
DF_TR.iloc[1, 10] = K_hvac_com
DF_TR.iloc[1, 11] = np.log(2) / T_hl_air
DF_TR.iloc[2, 4] = K_hnd_sur * E_sur_hnd * T_act_cab * (A_palm / A_cab) * (1 - (P_hnd_wash * E_hnd_wash))
DF_TR.iloc[2, 7] = K_hnd_sur * E_sur_hnd * T_ser * (N_cab_inf / N_remain) * (A_palm / A_cab) * (1 - (P_hnd_wash * E_hnd_wash))
DF_TR.iloc[2, 11] = np.log(2) / (T_hl_sur * (1 - R_disinf))
DF_TR.iloc[3, 4] = K_hnd_sur * E_sur_hnd * T_act_com * (A_palm / A_com_all) * (1 - (P_hnd_wash * E_hnd_wash))
DF_TR.iloc[3, 7] = K_hnd_sur * E_sur_hnd * T_act_com * (A_palm / A_com_all) * (1 - (P_hnd_wash * E_hnd_wash))
DF_TR.iloc[3, 11] = np.log(2) / (T_hl_sur * (1 - R_disinf))
DF_TR.iloc[4, 2] = K_hnd_sur * E_hnd_sur * T_act_cab
DF_TR.iloc[4, 3] = K_hnd_sur * E_hnd_sur * T_act_com
DF_TR.iloc[4, 5] = K_hnd_fac * E_hnd_mm * (T_act_cab + (T_act_com * (1 - F_cover)))
DF_TR.iloc[4, 11] = K_inc_hnd
DF_TR.iloc[7, 2] = (N_cab_inf / N_remain) * K_hnd_sur * E_hnd_sur * T_ser
DF_TR.iloc[7, 3] = K_hnd_sur * E_hnd_sur * T_act_com
DF_TR.iloc[7, 8] = K_hnd_fac * E_hnd_mm * (T_act_cab + (T_act_com * (1 - F_cover)))
DF_TR.iloc[7, 11] = K_inc_hnd

MCM = np.zeros((12, 12))
DF_sum = DF_TR.sum(axis=1)/3600

for i in range(12):
    MCM[i, i] = np.exp(-1*DF_sum.iloc[i])

for i in range(12):
    for j in range(12):
        if i != j:
            if DF_sum.iloc[i] > 0:
                MCM[i, j] = ((DF_TR.iloc[i, j]/3600)/DF_sum.iloc[i])*(1-MCM[i, i])

# 1-4- Estimating number of RNA copies in URT and LRT of susceptible individuals
TE = ER                   # Temporary emission rate matrix for the code
BF = int(3600/N_bre)      # Breathing Friquency was assumed every 4 seconds
PT = int(24*3600/BF)

for i in range(BF):
    MCM = MCM.dot(MCM)
for j in range(PT):
    TE = TE.dot(MCM) + ER

# 1-5- Estimating the infectious dose for upper and lower respiratory tracts
DF_ID50_Results = pd.DataFrame(np.zeros((6, 7)),
                               columns=['Reproduction Number', 'ID50_URT_F=1', 'ID50_URT_F=10', 'ID50_URT_F=100',
                                        'ID50_LRT_F=1', 'ID50_LRT_F=10', 'ID50_LRT_F=100'])
DF_Infectivity = pd.DataFrame(np.zeros((6, 7)),
                              columns=['Reproduction Number', 'Infectivity_URT_F=1', 'Infectivity_URT_F=10',
                                       'Infectivity_URT_F=100', 'Infectivity_LRT_F=1', 'Infectivity_LRT_F=10',
                                       'Infectivity_LRT_F=100'])
N_urt = TE.item(8)
N_lrt = TE.item(9)

for j in range(6):
    R0 = int(j+1)  # Effective Reproduction Number for the time period of the index case presence(1-6)
    P_inf = R0 / N_sus_com
    DF_Infectivity.iloc[j, 0] = R0
    DF_ID50_Results.iloc[j, 0] = R0
    for i in range(3):
        F_id = 10**i                         # Proprtion of ID50_urt/ID50_lrt
        a_urt = np.log(1-P_inf)*(-1)/(N_urt+(F_id*N_lrt))
        a_lrt = a_urt*F_id
        DF_Infectivity.iloc[j, i + 1] = a_urt
        DF_Infectivity.iloc[j, i + 4] = a_lrt
        DF_ID50_Results.iloc[j, i + 1] = np.log(2) / a_urt
        DF_ID50_Results.iloc[j, i + 4] = np.log(2) / a_lrt

# 2- Validation Period: Applying Advanced Epidemic Model
DF_reed_frost = pd.read_excel(
    r'C:\Users\paa009\Dropbox (Harvard University)\COVID-19_Harvard-IIT\Calculation\Cruise_Ship_Timeline_ZK.xlsx',
    sheet_name='Data_Frame')

STR_C = str(C) + '_'
STR_W = str(W) + '_'
STR_F = str(F_inf)

writer = pd.ExcelWriter(
    r'C:\Users\paa009\Dropbox (Harvard University)\COVID-19_Harvard-IIT\Calculation\COVID19_' + STR_C + STR_W + STR_F + 'S.xlsx',
    engine='xlsxwriter')

writer_acc = pd.ExcelWriter(
    r'C:\Users\paa009\Dropbox (Harvard University)\COVID-19_Harvard-IIT\Calculation\COVID19_Results_Accepted.xlsx',
    engine='xlsxwriter')

DF_Infectivity.to_excel(writer, sheet_name='Infectivity')
DF_ID50_Results.to_excel(writer, sheet_name='ID50')
DF_Infectivity.to_excel(writer_acc, sheet_name='Infectivity')
DF_ID50_Results.to_excel(writer_acc, sheet_name='ID50')

DF_Temp_0 = pd.DataFrame(np.zeros((36, 38+36)), columns=['R2_cum', 'R2_dai', 'Inc_per', 'Sub_cli_inf_per', 'Asym/sym_emi',
                                                         'Emi_sce', 'Sho_rng_sce', 'R0_pri', 'ID50_URT/LRT', 'Inf_ctr_eff_sce',
                                                         'Inf_cas_tot_cab', 'Inf_cas_tot_com', 'Inf_ctb_cab', 'Inf_ctb_com',
                                                         'Inf_ctb_tot_inh_lon_cab', 'Inf_ctb_tot_inh_lon_com',
                                                         'Inf_ctb_tot_inh_sho_cab', 'Inf_ctb_tot_inh_sho_com', 'Inf_ctb_tot_dir_spr_cab',
                                                         'Inf_ctb_tot_dir_spr_com', 'Inf_ctb_tot_fom_cab', 'Inf_ctb_tot_fom_com',
                                                         'Inf_ctb_bfr_inh_lon_cab', 'Inf_ctb_bfr_inh_lon_com', 'Inf_ctb_bfr_inh_sho_cab',
                                                         'Inf_ctb_bfr_inh_sho_com', 'Inf_ctb_bfr_dir_spr_cab', 'Inf_ctb_bfr_dir_spr_com',
                                                         'Inf_ctb_bfr_fom_cab', 'Inf_ctb_bfr_fom_com', 'Inf_ctb_aft_inh_lon_cab',
                                                         'Inf_ctb_aft_inh_lon_com', 'Inf_ctb_aft_inh_sho_cab', 'Inf_ctb_aft_inh_sho_com',
                                                         'Inf_ctb_aft_dir_spr_cab', 'Inf_ctb_aft_dir_spr_com', 'Inf_ctb_aft_fom_cab',
                                                         'Inf_ctb_aft_fom_com', 'R0_D00', 'R0_D01', 'R0_D02', 'R0_D03',
                                                         'R0_D04', 'R0_D05', 'R0_D06', 'R0_D07', 'R0_D08', 'R0_D09', 'R0_D10',
                                                         'R0_D11', 'R0_D12', 'R0_D13', 'R0_D14', 'R0_D15', 'R0_D16', 'R0_D17',
                                                         'R0_D18', 'R0_D19', 'R0_D20', 'R0_D21', 'R0_D22', 'R0_D23', 'R0_D24',
                                                         'R0_D25', 'R0_D26', 'R0_D27', 'R0_D28', 'R0_D29', 'R0_D30', 'R0_D31',
                                                         'R0_D32', 'R0_D33', 'R0_D34', 'R0_D35'])

DF_Temp_0['Inc_per'] = C
DF_Temp_0['Sub_cli_inf_per'] = W
DF_Temp_0['Asym/sym_emi'] = F_inf
No_Temp_0 = 0
No_R2 = 0

for a in range(R0_cases):             # Changes the R0 assumption (1-6)
    for b in range(ID_cases):         # Changes the F assumption (1,10,100)
        for c in range(2):
            C_option = c + 1
            RF = np.array(DF_reed_frost)
            a_urt = DF_Infectivity.iloc[a, b + 1]
            a_lrt = DF_Infectivity.iloc[a, b + 4]

            # 2-1- First Period: January 20th-24th (index case as the only infector: 5 days)
            N_day_1 = int(5)
            for i in range(N_day_1):
                # 2-1-1 Including the input data for the second period
                N_inf = 1
                N_cab_inf = 1
                N_sus_cab = 0
                N_sus_com = 523 + 2666

                # 2-1-2 Generating emission rate matrix
                ER_val = ER

                # 2-1-3 Generating Markov chain matrix
                MCM_val = MCM

                # 2-1-4 Applying the Reed-Frost model
                TE_1 = ER_val                    # Temporary emission rate matrix for the code
                PT = int(24 * 3600 / BF)         # Number of time periods (number of breaths during the modeling period
                for j in range(BF):
                    MCM_val = MCM_val.dot(MCM_val)
                for k in range(PT):
                    TE_1 = TE_1.dot(MCM_val) + ER_val

                N_urt_cab = TE_1.item(5)
                N_lrt_cab = TE_1.item(6)
                N_urt_com = TE_1.item(8)
                N_lrt_com = TE_1.item(9)
                RF[i, 11] = N_urt_cab
                RF[i, 12] = N_lrt_cab
                RF[i, 13] = N_urt_com
                RF[i, 14] = N_lrt_com

                P_inf_cab = 1 - np.exp(-1 * ((a_urt * N_urt_cab) + (a_lrt * N_lrt_cab)))
                P_inf_com = 1 - np.exp(-1 * ((a_urt * N_urt_com) + (a_lrt * N_lrt_com)))
                RF[i + C, 5] = math.floor(P_inf_cab * N_sus_cab)
                RF[i + C, 6] = math.floor(P_inf_com * N_sus_com)
                RF[i + C, 7] = RF[i + C, 5] + RF[i + C, 6]
                RF[i + C, 9] = RF[i + C, 7] + RF[i + C - 1, 9]
                if RF[i, 1] > 0:
                    RF[i, 15] = RF[i + C, 7] / RF[i, 1]

                Temp_1 = RF[i + C - W - 1, 1] + RF[i + C, 7] - RF[i + C - W - 1, N_remove]
                if 3711 - RF[i + C - W, 9] - Temp_1 > 0:    # Sum of infected cases + infectors < total passengers
                    if Temp_1 > 0:                          # Number of infectors should be at least 1 after quarantine
                        RF[i + C - W, 1] = Temp_1
                    else:
                        RF[i + C - W, 1] = 0
                else:
                    RF[i + C - W, 1] = 3711 - RF[i + C - W, 9]

                Temp_2 = RF[i + C - W - 1, 2] + RF[i + C, 6]
                if Temp_2 < (3710 / 2):                # Number of staterooms should be lower than 1855
                    RF[i + C - W, 2] = Temp_2
                else:
                    RF[i + C - W, 2] = 3710 / 2

            # 2-2 Second Period: From January 25th to February 4th (start of the quarantine: 11 days)
            N_day_2 = int(11)
            for i in range(N_day_2):
                # 2-2-1 Including the input data for the second period
                sum_lat_cab = 0
                for l in range(C):
                    sum_lat_cab = sum_lat_cab + RF[l + i + N_day_1, 5]
                Temp_3 = (RF[i + N_day_1, 2] * 2) - RF[i + N_day_1, 1] - sum_lat_cab - RF[i + N_day_1 - 1, 9]
                if Temp_3 + RF[i + N_day_1 + C - 1, 9] > 3711:
                    RF[i + N_day_1, 3] = 3711 - RF[i + N_day_1 + C - 1, 9]
                else:
                    if Temp_3 > 0:
                        RF[i + N_day_1, 3] = Temp_3
                    else:
                        RF[i + N_day_1, 3] = 0
                if RF[i + N_day_1, 3] > RF[i + N_day_1, 2] - RF[i + N_day_1 - 1, 2]:
                    if RF[i + N_day_1, 2] - RF[i + N_day_1 - 1, 2] > 0:
                        RF[i + N_day_1, 3] = RF[i + N_day_1, 2] - RF[i + N_day_1 - 1, 2]
                    else:
                        RF[i + N_day_1, 3] = 0

                sum_lat_com = 0  # sum of infected individuals during the latent period
                for l in range(C):
                    sum_lat_com = sum_lat_com + RF[l + i + N_day_1, 6]
                Temp_4 = 3711 - (RF[i + N_day_1, 2] * 2) - sum_lat_com
                if Temp_4 > 0:
                    RF[i + N_day_1, 4] = Temp_4
                else:
                    RF[i + N_day_1, 4] = 0

                T_cab = 9 / 24  # Range (+/- 25%)
                if H_close_cab < 9:
                    T_close_cab = H_close_cab / 24
                else:
                    T_close_cab = 9 / 24
                T_com = 1 - T_cab
                T_close_close = H_close_com / 24
                T_act_cab = T_cab - T_close_cab  # Range (+/- 25%)
                T_act_com = T_com - T_close_com
                A_com_ind = 18000  # [m2]
                A_com_all = 18000 + 17000 + 3700  # [m2]
                P_close_cab = T_close_cab + (T_act_cab * A_dir_pre / A_cab)
                P_long_cab = T_cab - P_close_cab
                P_close_com = T_close_com + (T_act_com * A_dir_pre / A_com_all)
                P_long_com = T_com - P_close_com
                R_mask = 0
                F_cover = 0
                P_hnd_wash = 0.7
                E_hnd_wash = 0.725
                R_disinf = 0
                N_inf = RF[i + N_day_1, 1]
                N_cab_inf = RF[i + N_day_1, 2]
                N_sus_cab = RF[i + N_day_1, 3]
                N_sus_com = RF[i + N_day_1, 4]

                # 2-2-2 Generating emission rate matrix
                ER_val = np.zeros((1, 12))
                ER_val[0, 0] = T_cab * (E_aer / N_bre) * (P_sym_tot + ((1 - P_sym_tot) * F_inf))
                ER_val[0, 1] = T_com * N_inf * (E_aer / N_bre) * (P_sym_tot + ((1 - P_sym_tot) * F_inf)) * (1 - R_mask)
                ER_val[0, 2] = T_cab * (E_drp / N_bre) * (P_sym_tot + ((1 - P_sym_tot) * F_inf))
                ER_val[0, 3] = T_com * N_inf * (E_drp / N_bre) * (P_sym_tot + ((1 - P_sym_tot) * F_inf)) * (1 - R_mask)
                if T_mode == 1:
                    ER_val[0, 4] = (E_drp / N_bre) * P_close_cab * (A_palm / A_dir_inj) * (P_sym_tot + ((1 - P_sym_tot) * F_inf))
                    ER_val[0, 5] = (E_drp / N_bre) * P_close_cab * (A_mm / A_dir_inj) * (P_sym_tot + ((1 - P_sym_tot) * F_inf))
                    ER_val[0, 6] = (E_aer / N_bre) * P_close_cab * (V_bre / V_cone) * (P_sym_tot + ((1 - P_sym_tot) * F_inf))
                    ER_val[0, 7] = N_inf * (E_drp / N_bre) * P_close_com * (A_palm / A_dir_inj) * (P_sym_tot + ((1 - P_sym_tot) * F_inf)) * (1 - R_mask) * (1 - F_cover)
                    ER_val[0, 8] = N_inf * (E_drp / N_bre) * P_close_com * (A_mm / A_dir_inj) * (P_sym_tot + ((1 - P_sym_tot) * F_inf)) * (1 - R_mask) * (1 - F_cover)
                    ER_val[0, 9] = N_inf * (E_aer / N_bre) * P_close_com * (V_bre / V_cone) * (P_sym_tot + ((1 - P_sym_tot) * F_inf)) * ((1 - R_mask) ** 2)

                # 2-2-3 Generating Markov chain matrix
                DF_TR = pd.DataFrame(np.zeros((12, 12)))
                DF_TR.iloc[0, 1] = K_hvac_cab * P_inter
                DF_TR.iloc[0, 2] = K_dep
                DF_TR.iloc[0, 6] = P_long_cab * (I_inh / 24) / V_cab
                DF_TR.iloc[0, 9] = (N_cab_inf / N_remain) * T_ser * (I_inh / (24 * V_cab)) * (1 - R_mask)
                DF_TR.iloc[0, 10] = K_hvac_cab
                DF_TR.iloc[0, 11] = np.log(2) / T_hl_air
                DF_TR.iloc[1, 3] = K_dep
                DF_TR.iloc[1, 6] = (P_long_com / 2) * (I_inh / (24 * V_com)) * (1 - R_mask)
                DF_TR.iloc[1, 9] = (P_long_com / 2) * (I_inh / (24 * V_com)) * (1 - R_mask)
                DF_TR.iloc[1, 10] = K_hvac_com
                DF_TR.iloc[1, 11] = np.log(2) / T_hl_air
                DF_TR.iloc[2, 4] = K_hnd_sur * E_sur_hnd * T_act_cab * (A_palm / A_cab) * (1 - (P_hnd_wash * E_hnd_wash))
                DF_TR.iloc[2, 7] = K_hnd_sur * E_sur_hnd * T_ser * (N_cab_inf / N_remain) * (A_palm / A_cab) * (1 - (P_hnd_wash * E_hnd_wash))
                DF_TR.iloc[2, 11] = np.log(2) / (T_hl_sur * (1 - R_disinf))
                DF_TR.iloc[3, 4] = K_hnd_sur * E_sur_hnd * T_act_com * (A_palm / A_com_all) * (1 - (P_hnd_wash * E_hnd_wash))
                DF_TR.iloc[3, 7] = K_hnd_sur * E_sur_hnd * T_act_com * (A_palm / A_com_all) * (1 - (P_hnd_wash * E_hnd_wash))
                DF_TR.iloc[3, 11] = np.log(2) / (T_hl_sur * (1 - R_disinf))
                DF_TR.iloc[4, 2] = K_hnd_sur * E_hnd_sur * T_act_cab
                DF_TR.iloc[4, 3] = K_hnd_sur * E_hnd_sur * T_act_com
                DF_TR.iloc[4, 5] = K_hnd_fac * E_hnd_mm * (T_act_cab + (T_act_com * (1 - F_cover)))
                DF_TR.iloc[4, 11] = K_inc_hnd
                DF_TR.iloc[7, 2] = (N_cab_inf / N_remain) * K_hnd_sur * E_hnd_sur * T_ser
                DF_TR.iloc[7, 3] = K_hnd_sur * E_hnd_sur * T_act_com
                DF_TR.iloc[7, 8] = K_hnd_fac * E_hnd_mm * (T_act_cab + (T_act_com * (1 - F_cover)))
                DF_TR.iloc[7, 11] = K_inc_hnd

                MCM_val = np.zeros((12, 12))
                DF_sum = DF_TR.sum(axis=1) / 3600
                for p in range(12):
                    MCM_val[p, p] = np.exp(-1 * DF_sum.iloc[p])
                for n in range(12):
                    for m in range(12):
                        if n != m:
                            if DF_sum.iloc[n] > 0:
                                MCM_val[n, m] = ((DF_TR.iloc[n, m] / 3600) / DF_sum.iloc[n]) * (1 - MCM_val[n, n])

                # 2-2-4 Applying the Reed-Frost model
                TE_2 = ER_val  # Temporary emission rate matrix for the code
                PT = int(24 * 3600 / BF)  # Number of time periods (number of breaths during one day of modeling period)
                for j in range(BF):
                    MCM_val = MCM_val.dot(MCM_val)
                for k in range(PT):
                    TE_2 = TE_2.dot(MCM_val) + ER_val

                N_urt_cab = TE_2.item(5)
                N_lrt_cab = TE_2.item(6)
                N_urt_com = TE_2.item(8)
                N_lrt_com = TE_2.item(9)
                RF[i + N_day_1, 11] = N_urt_cab
                RF[i + N_day_1, 12] = N_lrt_cab
                RF[i + N_day_1, 13] = N_urt_com
                RF[i + N_day_1, 14] = N_lrt_com

                P_inf_cab = 1 - np.exp(-1 * ((a_urt * N_urt_cab) + (a_lrt * N_lrt_cab)))
                P_inf_com = 1 - np.exp(-1 * ((a_urt * N_urt_com) + (a_lrt * N_lrt_com)))
                RF[i + N_day_1 + C, 5] = math.floor(P_inf_cab * N_sus_cab)
                RF[i + N_day_1 + C, 6] = math.floor(P_inf_com * N_sus_com)
                RF[i + N_day_1 + C, 7] = RF[i + N_day_1 + C, 5] + RF[i + N_day_1 + C, 6]
                RF[i + N_day_1 + C, 9] = RF[i + N_day_1 + C, 7] + RF[i + N_day_1 + C - 1, 9]
                if RF[i + N_day_1, 1] > 0:
                    RF[i + N_day_1, 15] = RF[i + N_day_1 + C, 7] / RF[i + N_day_1, 1]

                Temp_1 = RF[i + N_day_1 + C - W - 1, 1] + RF[i + N_day_1 + C, 7] - RF[i + N_day_1 + C - W - 1, N_remove]
                if 3711 - RF[i + N_day_1 + C - W, 9] - Temp_1 > 0:
                    if Temp_1 > 1:
                        RF[i + N_day_1 + C - W, 1] = Temp_1
                    else:
                        RF[i + N_day_1 + C - W, 1] = 1
                else:
                    Temp_5 = 3711 - RF[i + N_day_1 + C - W, 9]
                    if Temp_5 > 1:
                        RF[i + N_day_1 + C - W, 1] = Temp_5
                    else:
                        RF[i + N_day_1 + C - W, 1] = 1

                Temp_2 = RF[i + N_day_1 + C - W - 1, 2] + RF[i + N_day_1 + C, 6]
                if Temp_2 < 3710 / 2:
                    RF[i + N_day_1 + C - W, 2] = Temp_2
                else:
                    RF[i + N_day_1 + C - W, 2] = 3710 / 2

            # 2-3 Third Period: During the quarantine from February 5th to 24th (end of the quarantine: 20 days)
            N_day_3 = int(20)
            for i in range(N_day_3):
                # 2-3-1 Including the input data for the second period
                sum_lat_cab = 0
                for l in range(C):
                    sum_lat_cab = sum_lat_cab + RF[l + i + N_day_1 + N_day_2, 5]
                Temp_3 = (RF[i + N_day_1 + N_day_2, 2] * 2) - RF[i + N_day_1 + N_day_2, 1] - sum_lat_cab - RF[i + N_day_1 + N_day_2 - 1, 9]
                if Temp_3 + RF[i + N_day_1 + N_day_2 + C - 1, 9] > 3711:
                    RF[i + N_day_1 + N_day_2, 3] = 3711 - RF[i + N_day_1 + N_day_2 + C - 1, 9]
                else:
                    if Temp_3 > 0:
                        RF[i + N_day_1 + N_day_2, 3] = Temp_3
                    else:
                        RF[i + N_day_1 + N_day_2, 3] = 0
                if RF[i + N_day_1 + N_day_2, 3] > RF[i + N_day_1 + N_day_2, 2] - RF[i + N_day_1 + N_day_2 - 1, 2]:
                    if RF[i + N_day_1 + N_day_2, 2] - RF[i + N_day_1 + N_day_2 - 1, 2] > 0:
                        RF[i + N_day_1 + N_day_2, 3] = RF[i + N_day_1 + N_day_2, 2] - RF[i + N_day_1 + N_day_2 - 1, 2]
                    else:
                        RF[i + N_day_1 + N_day_2, 3] = 0

                sum_lat_com = 0  # sum of infected individuals during the latent period
                for l in range(C):
                    sum_lat_com = sum_lat_com + RF[l + i + N_day_1 + N_day_2, 6]
                Temp_4 = 3711 - (RF[i + N_day_1 + N_day_2, 2] * 2) - sum_lat_com
                if Temp_4 > 0:
                    RF[i + N_day_1 + N_day_2, 4] = Temp_4
                else:
                    RF[i + N_day_1 + N_day_2, 4] = 0

                T_cab = (((754+522)*23)+(523*18)+(1912*24))/(3711*24)      # Range (+/- 25%)
                if H_close_cab < 18:
                    T_close_cab = H_close_cab / 24
                    T_act_cab = (((754 + 522) * (23 - H_close_cab)) + (523 * (18 - H_close_cab)) + (1912 * (24 - H_close_cab))) / (3711 * 24)  # Range (+/- 25%)
                else:
                    T_close_cab = 18 / 24
                    T_act_cab = (((754 + 522) * (23 - 18)) + (523 * (18 - 18)) + (1912 * (24 - 18))) / (3711 * 24)  # Range (+/- 25%)
                T_com = 1 - T_cab
                T_close_com = H_close_com / 24
                T_act_com = T_com - T_close_com
                A_com_ind = 3700 + 4000           # [m2]
                A_com_all = 3700 + 4000 + 17000   # [m2]
                P_close_cab = T_close_cab + (T_act_cab * A_dir_pre / A_cab)
                P_long_cab = T_cab - P_close_cab
                P_close_com = T_close_com + (T_act_com * A_dir_pre / A_com_all)
                P_long_com = T_com - P_close_com
                if C_option == 1:
                    R_mask = 0.95
                    F_cover = 0.54
                    P_hnd_wash = 0.90
                    E_hnd_wash = 0.90
                    R_disinf = 0.725
                elif C_option == 2:
                    R_mask = 0.99
                    F_cover = 0.54
                    P_hnd_wash = 0.99
                    E_hnd_wash = 0.99
                    R_disinf = 0.99

                N_inf = RF[i + N_day_1 + N_day_2, 1]
                N_cab_inf = RF[i + N_day_1 + N_day_2, 2]
                N_sus_cab = RF[i + N_day_1 + N_day_2, 3]
                N_sus_com = RF[i + N_day_1 + N_day_2, 4]

                # 2-3-2 Generating emission rate matrix
                ER_val = np.zeros((1, 12))
                ER_val[0, 0] = T_cab * (E_aer / N_bre) * (P_sym_tot + ((1 - P_sym_tot) * F_inf))
                ER_val[0, 1] = T_com * N_inf * (E_aer / N_bre) * (P_sym_tot + ((1 - P_sym_tot) * F_inf)) * (1 - R_mask)
                ER_val[0, 2] = T_cab * (E_drp / N_bre) * (P_sym_tot + ((1 - P_sym_tot) * F_inf))
                ER_val[0, 3] = T_com * N_inf * (E_drp / N_bre) * (P_sym_tot + ((1 - P_sym_tot) * F_inf)) * (1 - R_mask)
                if T_mode == 1:
                    ER_val[0, 4] = (E_drp / N_bre) * P_close_cab * (A_palm / A_dir_inj) * (P_sym_tot + ((1 - P_sym_tot) * F_inf))
                    ER_val[0, 5] = (E_drp / N_bre) * P_close_cab * (A_mm / A_dir_inj) * (P_sym_tot + ((1 - P_sym_tot) * F_inf))
                    ER_val[0, 6] = (E_aer / N_bre) * P_close_cab * (V_bre / V_cone) * (P_sym_tot + ((1 - P_sym_tot) * F_inf))
                    ER_val[0, 7] = N_inf * (E_drp / N_bre) * P_close_com * (A_palm / A_dir_inj) * (P_sym_tot + ((1 - P_sym_tot) * F_inf)) * (1 - R_mask) * (1 - F_cover)
                    ER_val[0, 8] = N_inf * (E_drp / N_bre) * P_close_com * (A_mm / A_dir_inj) * (P_sym_tot + ((1 - P_sym_tot) * F_inf)) * (1 - R_mask) * (1 - F_cover)
                    ER_val[0, 9] = N_inf * (E_aer / N_bre) * P_close_com * (V_bre / V_cone) * (P_sym_tot + ((1 - P_sym_tot) * F_inf)) * ((1 - R_mask) ** 2)

                # 2-3-3 Generating Markov chain matrix
                DF_TR = pd.DataFrame(np.zeros((12, 12)))
                DF_TR.iloc[0, 1] = K_hvac_cab * P_inter
                DF_TR.iloc[0, 2] = K_dep
                DF_TR.iloc[0, 6] = P_long_cab * (I_inh / 24) / V_cab
                DF_TR.iloc[0, 9] = (N_cab_inf / N_remain) * T_ser * (I_inh / (24 * V_cab)) * (1 - R_mask)
                DF_TR.iloc[0, 10] = K_hvac_cab
                DF_TR.iloc[0, 11] = np.log(2) / T_hl_air
                DF_TR.iloc[1, 3] = K_dep
                DF_TR.iloc[1, 6] = (P_long_com/ 2) * (I_inh / (24 * V_com)) * (1 - R_mask)
                DF_TR.iloc[1, 9] = (P_long_com / 2) * (I_inh / (24 * V_com)) * (1 - R_mask)
                DF_TR.iloc[1, 10] = K_hvac_com
                DF_TR.iloc[1, 11] = np.log(2) / T_hl_air
                DF_TR.iloc[2, 4] = K_hnd_sur * E_sur_hnd * T_act_cab * (A_palm / A_cab) * (1 - (P_hnd_wash * E_hnd_wash))
                DF_TR.iloc[2, 7] = K_hnd_sur * E_sur_hnd * T_ser * (N_cab_inf / N_remain) * (A_palm / A_cab) * (1 - (P_hnd_wash * E_hnd_wash))
                DF_TR.iloc[2, 11] = np.log(2) / (T_hl_sur * (1 - R_disinf))
                DF_TR.iloc[3, 4] = K_hnd_sur * E_sur_hnd * T_act_com * (A_palm / A_com_all) * (1 - (P_hnd_wash * E_hnd_wash))
                DF_TR.iloc[3, 7] = K_hnd_sur * E_sur_hnd * T_act_com * (A_palm / A_com_all) * (1 - (P_hnd_wash * E_hnd_wash))
                DF_TR.iloc[3, 11] = np.log(2) / (T_hl_sur * (1 - R_disinf))
                DF_TR.iloc[4, 2] = K_hnd_sur * E_hnd_sur * T_act_cab
                DF_TR.iloc[4, 3] = K_hnd_sur * E_hnd_sur * T_act_com
                DF_TR.iloc[4, 5] = K_hnd_fac * E_hnd_mm * (T_act_cab + (T_act_com * (1 - F_cover)))
                DF_TR.iloc[4, 11] = K_inc_hnd
                DF_TR.iloc[7, 2] = (N_cab_inf / N_remain) * K_hnd_sur * E_hnd_sur * T_ser
                DF_TR.iloc[7, 3] = K_hnd_sur * E_hnd_sur * T_act_com
                DF_TR.iloc[7, 8] = K_hnd_fac * E_hnd_mm * (T_act_cab + (T_act_com * (1 - F_cover)))
                DF_TR.iloc[7, 11] = K_inc_hnd

                MCM_val = np.zeros((12, 12))
                DF_sum = DF_TR.sum(axis=1) / 3600
                for p in range(12):
                    MCM_val[p, p] = np.exp(-1 * DF_sum.iloc[p])
                for n in range(12):
                    for m in range(12):
                        if n != m:
                            if DF_sum.iloc[n] > 0:
                                MCM_val[n, m] = ((DF_TR.iloc[n, m] / 3600) / DF_sum.iloc[n]) * (1 - MCM_val[n, n])

                # 2-3-4 Applying the Reed-Frost model
                TE_3 = ER_val  # Temporary emission rate matrix for the code
                PT = int(24 * 3600 / BF)  # Number of time periods (number of breaths during one day of modeling period)
                for j in range(BF):
                    MCM_val = MCM_val.dot(MCM_val)
                for k in range(PT):
                    TE_3 = TE_3.dot(MCM_val) + ER_val

                N_urt_cab = TE_3.item(5)
                N_lrt_cab = TE_3.item(6)
                N_urt_com = TE_3.item(8)
                N_lrt_com = TE_3.item(9)
                RF[i + N_day_1 + N_day_2, 11] = N_urt_cab
                RF[i + N_day_1 + N_day_2, 12] = N_lrt_cab
                RF[i + N_day_1 + N_day_2, 13] = N_urt_com
                RF[i + N_day_1 + N_day_2, 14] = N_lrt_com

                P_inf_cab = 1 - np.exp(-1 * ((a_urt * N_urt_cab) + (a_lrt * N_lrt_cab)))
                P_inf_com = 1 - np.exp(-1 * ((a_urt * N_urt_com) + (a_lrt * N_lrt_com)))
                RF[i + N_day_1 + N_day_2 + C, 5] = math.floor(P_inf_cab * N_sus_cab)
                RF[i + N_day_1 + N_day_2 + C, 6] = math.floor(P_inf_com * N_sus_com)
                RF[i + N_day_1 + N_day_2 + C, 7] = RF[i + N_day_1 + N_day_2 + C, 5] + RF[i + N_day_1 + N_day_2 + C, 6]
                RF[i + N_day_1 + N_day_2 + C, 9] = RF[i + N_day_1 + N_day_2 + C, 7] + RF[i + N_day_1 + N_day_2 + C - 1, 9]
                if RF[i + N_day_1 + N_day_2, 1] > 0:
                    RF[i + N_day_1 + N_day_2, 15] = RF[i + N_day_1 + N_day_2 + C, 7] / RF[i + N_day_1 + N_day_2, 1]

                Temp_1 = RF[i + N_day_1 + N_day_2 + C - W - 1, 1] + RF[i + N_day_1 + N_day_2 + C, 7] - RF[i + N_day_1 + N_day_2 + C - W - 1, N_remove]
                if 3711 - RF[i + N_day_1 + N_day_2 + C - W, 9] - Temp_1 > 0:
                    if Temp_1 > 1:
                        RF[i + N_day_1 + N_day_2 + C - W, 1] = Temp_1
                    else:
                        RF[i + N_day_1 + N_day_2 + C - W, 1] = 1
                else:
                    Temp_5 = 3711 - RF[i + N_day_1 + N_day_2 + C - W, 9]
                    if Temp_5 > 1:
                        RF[i + N_day_1 + N_day_2 + C - W, 1] = Temp_5
                    else:
                        RF[i + N_day_1 + N_day_2 + C - W, 1] = 1

                Temp_2 = RF[i + N_day_1 + N_day_2 + C - W - 1, 2] + RF[i + N_day_1 + N_day_2 + C, 6]
                if Temp_2 < 3710 / 2:
                    RF[i + N_day_1 + N_day_2 + C - W, 2] = Temp_2
                else:
                    RF[i + N_day_1 + N_day_2 + C - W, 2] = 3710 / 2

            # 3- Extracting the model outcomes + estimating daily and cumulative R2 values + R0 values
            STR_R0 = str(a+1)
            INT_ID = 10**b
            STR_ID = str(INT_ID)
            if C_option == 1:
                STR_Eff = 'M'
            elif C_option == 2:
                STR_Eff = 'H'
            else:
                STR_Eff = 'NA'
            STR_IC = str(C)
            STR_SI = str(W)
            STR_AS = str(F_inf)

            for y in range(36):
                DF_Temp_0.iloc[No_Temp_0, y + 38] = RF[y, 15]

            DF_Temp_1 = pd.DataFrame(RF, columns=['Day', 'No_infector', 'No_cab', 'No_sus_cab', 'No_sus_com', 'No_inf_cab',
                                                  'No_inf_com', 'No_inf_tot_est', 'No_inf_tot_rep', 'No_inf_est_cum',
                                                  'No_inf_rep_cum', 'No_RNA_URT_cab', 'No_RNA_LRT_cab', 'No_RNA_URT_com',
                                                  'No_RNA_LRT_com', 'Time_varied_R0', '(Y-f)^2 [daily-tot]', '(Y-Y_ave)^2 [daily-tot]',
                                                  '(Y-f)^2 [cum-tot]', '(Y-Y_ave)^2 [cum-tot]', 'No_RNA_URT_cab_fomite', 'No_RNA_LRT_cab_long',
                                                  'No_RNA_URT_com_fomite', 'No_RNA_LRT_com_long', 'Tot_inf_ctb_abs_cab', 'Tot_inf_ctb_abs_com',
                                                  'Tot_inf_ctb_pro_cab', 'Tot_inf_ctb_pro_com', 'Inf_ctb_inh_lon_cab', 'Inf_ctb_inh_lon_com',
                                                  'Inf_ctb_inh_sho_cab', 'Inf_ctb_inh_sho_com', 'Inf_ctb_dir_spr_cab', 'Inf_ctb_dir_spr_com',
                                                  'Inf_ctb_fom_cab', 'Inf_ctb_fom_com', 'Result_Descriptions', 'Result_Summary'])

            DF_Temp_2 = DF_Temp_1.drop(DF_Temp_1.index[[41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56]])

            DF_Temp_2['(Y-f)^2 [daily-tot]'] = (DF_Temp_2['No_inf_tot_est'] - DF_Temp_2['No_inf_tot_rep'])**2
            DF_Temp_2['(Y-Y_ave)^2 [daily-tot]'] = (DF_Temp_2['No_inf_tot_rep'] - DF_Temp_2['No_inf_tot_rep'].mean())**2
            DF_Temp_2['(Y-f)^2 [cum-tot]'] = (DF_Temp_2['No_inf_est_cum'] - DF_Temp_2['No_inf_rep_cum']) ** 2
            DF_Temp_2['(Y-Y_ave)^2 [cum-tot]'] = (DF_Temp_2['No_inf_rep_cum'] - DF_Temp_2['No_inf_rep_cum'].mean()) ** 2

            DF_Temp_2.iloc[0, 36] = 'R2_Cumulative'
            DF_Temp_2.iloc[0, 37] = 1 - (DF_Temp_2['(Y-f)^2 [cum-tot]'].sum() / DF_Temp_2['(Y-Y_ave)^2 [cum-tot]'].sum())
            DF_Temp_2.iloc[1, 36] = 'R2_Daily'
            DF_Temp_2.iloc[1, 37] = 1 - (DF_Temp_2['(Y-f)^2 [daily-tot]'].sum() / DF_Temp_2['(Y-Y_ave)^2 [daily-tot]'].sum())
            DF_Temp_2.iloc[2, 36] = 'Incubation_Period'
            DF_Temp_2.iloc[2, 37] = C
            DF_Temp_2.iloc[3, 36] = 'Sub-Clinical_Infectious_Period'
            DF_Temp_2.iloc[3, 37] = W
            DF_Temp_2.iloc[4, 36] = 'Asymptomatic/Symptomatic_Emission_Proportion'
            DF_Temp_2.iloc[4, 37] = F_inf
            DF_Temp_2.iloc[5, 36] = 'Emission Scenario'
            if E_option == 1:
                DF_Temp_2.iloc[5, 37] = 'Liu et al. (2020, Nature)'
            elif E_option == 2:
                DF_Temp_2.iloc[5, 37] = 'Chia et al. (2020, preprint)'
            elif E_option == 3:
                DF_Temp_2.iloc[5, 37] = 'E_aerosols = E_large_droplets'
            else:
                DF_Temp_2.iloc[5, 37] = 'TBD'
            DF_Temp_2.iloc[6, 36] = 'Short-Range_Interaction_Scenario'
            if H_option == 'S':
                DF_Temp_2.iloc[6, 37] = 'Standard'
            elif H_option == 'E':
                DF_Temp_2.iloc[6, 37] = 'Extended'
            else:
                DF_Temp_2.iloc[6, 37] = 'TBD'
            DF_Temp_2.iloc[7, 36] = 'Reproduction_Number'
            DF_Temp_2.iloc[7, 37] = a + 1
            DF_Temp_2.iloc[8, 36] = 'ID50_URT/ID50_LRT'
            DF_Temp_2.iloc[8, 37] = INT_ID
            DF_Temp_2.iloc[9, 36] = 'Infection Control Effeciency'
            if C_option == 1:
                DF_Temp_2.iloc[9, 37] = 'Moderate'
            elif C_option == 2:
                DF_Temp_2.iloc[9, 37] = 'High'
            else:
                DF_Temp_2.iloc[9, 37] = 'TBD'
            DF_Temp_2.iloc[10, 36] = 'Total_Infected_Cases_Staterooms'
            DF_Temp_2.iloc[10, 37] = DF_Temp_2['No_inf_cab'].sum()
            DF_Temp_2.iloc[11, 36] = 'Total_Infected_Cases_Public_Area'
            DF_Temp_2.iloc[11, 37] = DF_Temp_2['No_inf_com'].sum()
            DF_Temp_2.iloc[12, 36] = 'Infection_Contribution_Staterooms'
            DF_Temp_2.iloc[12, 37] = DF_Temp_2['No_inf_cab'].sum() / (DF_Temp_2['No_inf_cab'].sum() + DF_Temp_2['No_inf_com'].sum())
            DF_Temp_2.iloc[13, 36] = 'Infection_Contribution_Public_Area'
            DF_Temp_2.iloc[13, 37] = DF_Temp_2['No_inf_com'].sum() / (DF_Temp_2['No_inf_cab'].sum() + DF_Temp_2['No_inf_com'].sum())

            # 3-1- Extracting the contribution of Long-range transmission + Fomite
            if DF_Temp_2.iloc[0, 37] > 0.8:
                No_R2 = No_R2 + 1

                for z in range(36):
                    N_inf = DF_Temp_2.iloc[z, 1]
                    N_cab_inf = DF_Temp_2.iloc[z, 2]
                    N_sus_cab = DF_Temp_2.iloc[z, 3]
                    N_sus_com = DF_Temp_2.iloc[z, 4]

                    if z < 5:
                        T_cab = 9 / 24                      # Range (+/- 25%)
                        if H_close_cab < 9:
                            T_close_cab = H_close_cab / 24
                        else:
                            T_close_cab = 9 / 24
                        T_com = 1 - T_cab
                        T_close_com = H_close_com / 24
                        T_act_cab = T_cab - T_close_cab     # Range (+/- 25%)
                        T_act_com = T_com - T_close_com
                        A_com_ind = 18000  # [m2]
                        A_com_all = 18000 + 17000 + 3700    # [m2]
                        P_close_cab = T_close_cab + (T_act_cab * A_dir_pre / A_cab)
                        P_long_cab = T_cab - P_close_cab
                        P_close_com = T_close_com + (T_act_com * A_dir_pre / A_com_all)
                        P_long_com = T_com - P_close_com
                        R_mask = 0
                        F_cover = 0
                        P_hnd_wash = 0.7
                        E_hnd_wash = 0.725
                        R_disinf = 0

                        ER_mode = np.zeros((1, 12))
                        ER_mode[0, 0] = T_cab * (E_aer / N_bre)
                        ER_mode[0, 1] = T_com * N_inf * (E_aer / N_bre) * (1 - R_mask)
                        ER_mode[0, 2] = T_cab * (E_drp / N_bre)
                        ER_mode[0, 3] = T_com * N_inf * (E_drp / N_bre) * (1 - R_mask)

                        MCM_mode = MCM

                        TE_mode = ER_mode
                        for j in range(BF):
                            MCM_mode = MCM_mode.dot(MCM_mode)
                        for k in range(PT):
                            TE_mode = TE_mode.dot(MCM_mode) + ER_mode

                        DF_Temp_2.iloc[z, 20] = TE_mode.item(5)
                        DF_Temp_2.iloc[z, 21] = TE_mode.item(6)
                        DF_Temp_2.iloc[z, 22] = TE_mode.item(8)
                        DF_Temp_2.iloc[z, 23] = TE_mode.item(9)

                    elif z < 16:
                        T_cab = 9 / 24  # Range (+/- 25%)
                        if H_close_cab < 9:
                            T_close_cab = H_close_cab / 24
                        else:
                            T_close_cab = 9 / 24
                        T_com = 1 - T_cab
                        T_close_com = H_close_com / 24
                        T_act_cab = T_cab - T_close_cab  # Range (+/- 25%)
                        T_act_com = T_com - T_close_com
                        A_com_ind = 18000  # [m2]
                        A_com_all = 18000 + 17000 + 3700  # [m2]
                        P_close_cab = T_close_cab + (T_act_cab * A_dir_pre / A_cab)
                        P_long_cab = T_cab - P_close_cab
                        P_close_com = T_close_com + (T_act_com * A_dir_pre / A_com_all)
                        P_long_com = T_com - P_close_com
                        R_mask = 0
                        F_cover = 0
                        P_hnd_wash = 0.7
                        E_hnd_wash = 0.725
                        R_disinf = 0

                        ER_mode = np.zeros((1, 12))
                        ER_mode[0, 0] = T_cab * (E_aer / N_bre) * (P_sym_tot + ((1 - P_sym_tot) * F_inf))
                        ER_mode[0, 1] = T_com * N_inf * (E_aer / N_bre) * (P_sym_tot + ((1 - P_sym_tot) * F_inf)) * (1 - R_mask)
                        ER_mode[0, 2] = T_cab * (E_drp / N_bre) * (P_sym_tot + ((1 - P_sym_tot) * F_inf))
                        ER_mode[0, 3] = T_com * N_inf * (E_drp / N_bre) * (P_sym_tot + ((1 - P_sym_tot) * F_inf)) * (1 - R_mask)

                        DF_TR = pd.DataFrame(np.zeros((12, 12)))
                        DF_TR.iloc[0, 1] = K_hvac_cab * P_inter
                        DF_TR.iloc[0, 2] = K_dep
                        DF_TR.iloc[0, 6] = P_long_cab * (I_inh / 24) / V_cab
                        DF_TR.iloc[0, 9] = (N_cab_inf / N_remain) * T_ser * (I_inh / (24 * V_cab)) * (1 - R_mask)
                        DF_TR.iloc[0, 10] = K_hvac_cab
                        DF_TR.iloc[0, 11] = np.log(2) / T_hl_air
                        DF_TR.iloc[1, 3] = K_dep
                        DF_TR.iloc[1, 6] = (P_long_com / 2) * (I_inh / (24 * V_com)) * (1 - R_mask)
                        DF_TR.iloc[1, 9] = (P_long_com / 2) * (I_inh / (24 * V_com)) * (1 - R_mask)
                        DF_TR.iloc[1, 10] = K_hvac_com
                        DF_TR.iloc[1, 11] = np.log(2) / T_hl_air
                        DF_TR.iloc[2, 4] = K_hnd_sur * E_sur_hnd * T_act_cab * (A_palm / A_cab) * (1 - (P_hnd_wash * E_hnd_wash))
                        DF_TR.iloc[2, 7] = K_hnd_sur * E_sur_hnd * T_ser * (N_cab_inf / N_remain) * (A_palm / A_cab) * (1 - (P_hnd_wash * E_hnd_wash))
                        DF_TR.iloc[2, 11] = np.log(2) / (T_hl_sur * (1 - R_disinf))
                        DF_TR.iloc[3, 4] = K_hnd_sur * E_sur_hnd * T_act_com * (A_palm / A_com_all) * (1 - (P_hnd_wash * E_hnd_wash))
                        DF_TR.iloc[3, 7] = K_hnd_sur * E_sur_hnd * T_act_com * (A_palm / A_com_all) * (1 - (P_hnd_wash * E_hnd_wash))
                        DF_TR.iloc[3, 11] = np.log(2) / (T_hl_sur * (1 - R_disinf))
                        DF_TR.iloc[4, 2] = K_hnd_sur * E_hnd_sur * T_act_cab
                        DF_TR.iloc[4, 3] = K_hnd_sur * E_hnd_sur * T_act_com
                        DF_TR.iloc[4, 5] = K_hnd_fac * E_hnd_mm * (T_act_cab + (T_act_com * (1 - F_cover)))
                        DF_TR.iloc[4, 11] = K_inc_hnd
                        DF_TR.iloc[7, 2] = (N_cab_inf / N_remain) * K_hnd_sur * E_hnd_sur * T_ser
                        DF_TR.iloc[7, 3] = K_hnd_sur * E_hnd_sur * T_act_com
                        DF_TR.iloc[7, 8] = K_hnd_fac * E_hnd_mm * (T_act_cab + (T_act_com * (1 - F_cover)))
                        DF_TR.iloc[7, 11] = K_inc_hnd

                        MCM_mode = np.zeros((12, 12))
                        DF_sum = DF_TR.sum(axis=1) / 3600
                        for p in range(12):
                            MCM_mode[p, p] = np.exp(-1 * DF_sum.iloc[p])
                        for n in range(12):
                            for m in range(12):
                                if n != m:
                                    if DF_sum.iloc[n] > 0:
                                        MCM_mode[n, m] = ((DF_TR.iloc[n, m] / 3600) / DF_sum.iloc[n]) * (1 - MCM_mode[n, n])

                        TE_mode = ER_mode  # Temporary emission rate matrix for the code
                        for j in range(BF):
                            MCM_mode = MCM_mode.dot(MCM_mode)
                        for k in range(PT):
                            TE_mode = TE_mode.dot(MCM_mode) + ER_mode

                        DF_Temp_2.iloc[z, 20] = TE_mode.item(5)
                        DF_Temp_2.iloc[z, 21] = TE_mode.item(6)
                        DF_Temp_2.iloc[z, 22] = TE_mode.item(8)
                        DF_Temp_2.iloc[z, 23] = TE_mode.item(9)

                    elif z < 36:
                        T_cab = (((754 + 522) * 23) + (523 * 18) + (1912 * 24)) / (3711 * 24)  # Range (+/- 25%)
                        if H_close_cab < 18:
                            T_close_cab = H_close_cab / 24
                            T_act_cab = (((754 + 522) * (23 - H_close_cab)) + (523 * (18 - H_close_cab)) + (1912 * (24 - H_close_cab))) / (3711 * 24)  # Range (+/- 25%)
                        else:
                            T_close_cab = 18 / 24
                            T_act_cab = (((754 + 522) * (23 - 18)) + (523 * (18 - 18)) + (1912 * (24 - 18))) / (3711 * 24)  # Range (+/- 25%)
                        T_com = 1 - T_cab
                        T_close_com = H_close_com / 24
                        T_act_com = T_com - T_close_com
                        A_com_ind = 3700 + 4000  # [m2]
                        A_com_all = 3700 + 4000 + 17000  # [m2]
                        P_close_cab = T_close_cab + (T_act_cab * A_dir_pre / A_cab)
                        P_long_cab = T_cab - P_close_cab
                        P_close_com = T_close_com + (T_act_com * A_dir_pre / A_com_all)
                        P_long_com = T_com - P_close_com
                        if C_option == 1:
                            R_mask = 0.95
                            F_cover = 0.54
                            P_hnd_wash = 0.90
                            E_hnd_wash = 0.90
                            R_disinf = 0.725
                        elif C_option == 2:
                            R_mask = 0.99
                            F_cover = 0.54
                            P_hnd_wash = 0.99
                            E_hnd_wash = 0.99
                            R_disinf = 0.99

                        ER_mode = np.zeros((1, 12))
                        ER_mode[0, 0] = T_cab * (E_aer / N_bre) * (P_sym_tot + ((1 - P_sym_tot) * F_inf))
                        ER_mode[0, 1] = T_com * N_inf * (E_aer / N_bre) * (P_sym_tot + ((1 - P_sym_tot) * F_inf)) * (1 - R_mask)
                        ER_mode[0, 2] = T_cab * (E_drp / N_bre) * (P_sym_tot + ((1 - P_sym_tot) * F_inf))
                        ER_mode[0, 3] = T_com * N_inf * (E_drp / N_bre) * (P_sym_tot + ((1 - P_sym_tot) * F_inf)) * (1 - R_mask)

                        DF_TR = pd.DataFrame(np.zeros((12, 12)))
                        DF_TR.iloc[0, 1] = K_hvac_cab * P_inter
                        DF_TR.iloc[0, 2] = K_dep
                        DF_TR.iloc[0, 6] = P_long_cab * (I_inh / 24) / V_cab
                        DF_TR.iloc[0, 9] = (N_cab_inf / N_remain) * T_ser * (I_inh / (24 * V_cab)) * (1 - R_mask)
                        DF_TR.iloc[0, 10] = K_hvac_cab
                        DF_TR.iloc[0, 11] = np.log(2) / T_hl_air
                        DF_TR.iloc[1, 3] = K_dep
                        DF_TR.iloc[1, 6] = (P_long_com / 2) * (I_inh / (24 * V_com)) * (1 - R_mask)
                        DF_TR.iloc[1, 9] = (P_long_com / 2) * (I_inh / (24 * V_com)) * (1 - R_mask)
                        DF_TR.iloc[1, 10] = K_hvac_com
                        DF_TR.iloc[1, 11] = np.log(2) / T_hl_air
                        DF_TR.iloc[2, 4] = K_hnd_sur * E_sur_hnd * T_act_cab * (A_palm / A_cab) * (1 - (P_hnd_wash * E_hnd_wash))
                        DF_TR.iloc[2, 7] = K_hnd_sur * E_sur_hnd * T_ser * (N_cab_inf / N_remain) * (A_palm / A_cab) * (1 - (P_hnd_wash * E_hnd_wash))
                        DF_TR.iloc[2, 11] = np.log(2) / (T_hl_sur * (1 - R_disinf))
                        DF_TR.iloc[3, 4] = K_hnd_sur * E_sur_hnd * T_act_com * (A_palm / A_com_all) * (1 - (P_hnd_wash * E_hnd_wash))
                        DF_TR.iloc[3, 7] = K_hnd_sur * E_sur_hnd * T_act_com * (A_palm / A_com_all) * (1 - (P_hnd_wash * E_hnd_wash))
                        DF_TR.iloc[3, 11] = np.log(2) / (T_hl_sur * (1 - R_disinf))
                        DF_TR.iloc[4, 2] = K_hnd_sur * E_hnd_sur * T_act_cab
                        DF_TR.iloc[4, 3] = K_hnd_sur * E_hnd_sur * T_act_com
                        DF_TR.iloc[4, 5] = K_hnd_fac * E_hnd_mm * (T_act_cab + (T_act_com * (1 - F_cover)))
                        DF_TR.iloc[4, 11] = K_inc_hnd
                        DF_TR.iloc[7, 2] = (N_cab_inf / N_remain) * K_hnd_sur * E_hnd_sur * T_ser
                        DF_TR.iloc[7, 3] = K_hnd_sur * E_hnd_sur * T_act_com
                        DF_TR.iloc[7, 8] = K_hnd_fac * E_hnd_mm * (T_act_cab + (T_act_com * (1 - F_cover)))
                        DF_TR.iloc[7, 11] = K_inc_hnd

                        MCM_mode = np.zeros((12, 12))
                        DF_sum = DF_TR.sum(axis=1) / 3600
                        for p in range(12):
                            MCM_mode[p, p] = np.exp(-1 * DF_sum.iloc[p])
                        for n in range(12):
                            for m in range(12):
                                if n != m:
                                    if DF_sum.iloc[n] > 0:
                                        MCM_mode[n, m] = ((DF_TR.iloc[n, m] / 3600) / DF_sum.iloc[n]) * (1 - MCM_mode[n, n])

                        TE_mode = ER_mode  # Temporary emission rate matrix for the code
                        for j in range(BF):
                            MCM_mode = MCM_mode.dot(MCM_mode)
                        for k in range(PT):
                            TE_mode = TE_mode.dot(MCM_mode) + ER_mode

                        DF_Temp_2.iloc[z, 20] = TE_mode.item(5)
                        DF_Temp_2.iloc[z, 21] = TE_mode.item(6)
                        DF_Temp_2.iloc[z, 22] = TE_mode.item(8)
                        DF_Temp_2.iloc[z, 23] = TE_mode.item(9)

                for z in range(36):
                    DF_Temp_2.iloc[z, 24] = (1 - np.exp(-1 * DF_Temp_2.iloc[z, 21] * a_lrt)) + (1 - np.exp(-1 * (DF_Temp_2.iloc[z, 12] - DF_Temp_2.iloc[z, 21]) * a_lrt)) + (1 - np.exp(-1 * (DF_Temp_2.iloc[z, 11] - DF_Temp_2.iloc[z, 20]) * a_urt)) + (1 - np.exp(-1 * DF_Temp_2.iloc[z, 20] * a_urt))
                    DF_Temp_2.iloc[z, 25] = (1 - np.exp(-1 * DF_Temp_2.iloc[z, 23] * a_lrt)) + (1 - np.exp(-1 * (DF_Temp_2.iloc[z, 14] - DF_Temp_2.iloc[z, 23]) * a_lrt)) + (1 - np.exp(-1 * (DF_Temp_2.iloc[z, 13] - DF_Temp_2.iloc[z, 22]) * a_urt)) + (1 - np.exp(-1 * DF_Temp_2.iloc[z, 22] * a_urt))
                    DF_Temp_2.iloc[z, 26] = DF_Temp_1.iloc[z + C, 5] / (DF_Temp_2['No_inf_cab'].sum() + DF_Temp_2['No_inf_com'].sum())
                    DF_Temp_2.iloc[z, 27] = DF_Temp_1.iloc[z + C, 6] / (DF_Temp_2['No_inf_cab'].sum() + DF_Temp_2['No_inf_com'].sum())
                    DF_Temp_2.iloc[z, 28] = (1 - np.exp(-1 * DF_Temp_2.iloc[z, 21] * a_lrt)) * DF_Temp_2.iloc[z, 26] / DF_Temp_2.iloc[z, 24]
                    DF_Temp_2.iloc[z, 29] = (1 - np.exp(-1 * DF_Temp_2.iloc[z, 23] * a_lrt)) * DF_Temp_2.iloc[z, 27] / DF_Temp_2.iloc[z, 25]
                    DF_Temp_2.iloc[z, 30] = (1 - np.exp(-1 * (DF_Temp_2.iloc[z, 12] - DF_Temp_2.iloc[z, 21]) * a_lrt)) * DF_Temp_2.iloc[z, 26] / DF_Temp_2.iloc[z, 24]
                    DF_Temp_2.iloc[z, 31] = (1 - np.exp(-1 * (DF_Temp_2.iloc[z, 14] - DF_Temp_2.iloc[z, 23]) * a_lrt)) * DF_Temp_2.iloc[z, 27] / DF_Temp_2.iloc[z, 25]
                    DF_Temp_2.iloc[z, 32] = (1 - np.exp(-1 * (DF_Temp_2.iloc[z, 11] - DF_Temp_2.iloc[z, 20]) * a_urt)) * DF_Temp_2.iloc[z, 26] / DF_Temp_2.iloc[z, 24]
                    DF_Temp_2.iloc[z, 33] = (1 - np.exp(-1 * (DF_Temp_2.iloc[z, 13] - DF_Temp_2.iloc[z, 22]) * a_urt)) * DF_Temp_2.iloc[z, 27] / DF_Temp_2.iloc[z, 25]
                    DF_Temp_2.iloc[z, 34] = (1 - np.exp(-1 * DF_Temp_2.iloc[z, 20] * a_urt)) * DF_Temp_2.iloc[z, 26] / DF_Temp_2.iloc[z, 24]
                    DF_Temp_2.iloc[z, 35] = (1 - np.exp(-1 * DF_Temp_2.iloc[z, 22] * a_urt)) * DF_Temp_2.iloc[z, 27] / DF_Temp_2.iloc[z, 25]

                DF_Temp_3 = DF_Temp_2
                colm = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 36, 37]

                DF_Temp_3 = DF_Temp_3.drop(DF_Temp_3.columns[colm], axis=1)
                DF_Temp_3 = DF_Temp_3.drop(DF_Temp_3.index[[16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35]])
                No_Temp_3 = DF_Temp_3['Inf_ctb_inh_lon_cab'].sum() + DF_Temp_3['Inf_ctb_inh_lon_com'].sum() + DF_Temp_3['Inf_ctb_inh_sho_cab'].sum() + DF_Temp_3['Inf_ctb_inh_sho_com'].sum() + DF_Temp_3['Inf_ctb_dir_spr_cab'].sum() + DF_Temp_3['Inf_ctb_dir_spr_com'].sum() + DF_Temp_3['Inf_ctb_fom_cab'].sum() + DF_Temp_3['Inf_ctb_fom_com'].sum()

                DF_Temp_2.iloc[14, 36] = 'Infection_Contribution_Inhalation_Long_Range_Staterooms'
                DF_Temp_2.iloc[14, 37] = DF_Temp_2['Inf_ctb_inh_lon_cab'].sum()
                DF_Temp_2.iloc[15, 36] = 'Infection_Contribution_Inhalation_Long_Range_Public_Area'
                DF_Temp_2.iloc[15, 37] = DF_Temp_2['Inf_ctb_inh_lon_com'].sum()
                DF_Temp_2.iloc[16, 36] = 'Infection_Contribution_Inhalation_Short_Range_Staterooms'
                DF_Temp_2.iloc[16, 37] = DF_Temp_2['Inf_ctb_inh_sho_cab'].sum()
                DF_Temp_2.iloc[17, 36] = 'Infection_Contribution_Inhalation_Short_Range_Public_Area'
                DF_Temp_2.iloc[17, 37] = DF_Temp_2['Inf_ctb_inh_sho_com'].sum()
                DF_Temp_2.iloc[18, 36] = 'Infection_Contribution_Direct_Spray_Short_Range_Staterooms'
                DF_Temp_2.iloc[18, 37] = DF_Temp_2['Inf_ctb_dir_spr_cab'].sum()
                DF_Temp_2.iloc[19, 36] = 'Infection_Contribution_Direct_Spray_Short_Range_Public_Area'
                DF_Temp_2.iloc[19, 37] = DF_Temp_2['Inf_ctb_dir_spr_com'].sum()
                DF_Temp_2.iloc[20, 36] = 'Infection_Contribution_Fomite_Staterooms'
                DF_Temp_2.iloc[20, 37] = DF_Temp_2['Inf_ctb_fom_cab'].sum()
                DF_Temp_2.iloc[21, 36] = 'Infection_Contribution_Fomite_Public_Area'
                DF_Temp_2.iloc[21, 37] = DF_Temp_2['Inf_ctb_fom_com'].sum()
                DF_Temp_2.iloc[22, 36] = 'Infection_Contribution_Before_Quarantine_Inhalation_Long_Range_Staterooms'
                DF_Temp_2.iloc[22, 37] = DF_Temp_3['Inf_ctb_inh_lon_cab'].sum() / No_Temp_3
                DF_Temp_2.iloc[23, 36] = 'Infection_Contribution_Before_Quarantine_Inhalation_Long_Range_Public_Area'
                DF_Temp_2.iloc[23, 37] = DF_Temp_3['Inf_ctb_inh_lon_com'].sum() / No_Temp_3
                DF_Temp_2.iloc[24, 36] = 'Infection_Contribution_Before_Quarantine_Inhalation_Short_Range_Staterooms'
                DF_Temp_2.iloc[24, 37] = DF_Temp_3['Inf_ctb_inh_sho_cab'].sum() / No_Temp_3
                DF_Temp_2.iloc[25, 36] = 'Infection_Contribution_Before_Quarantine_Inhalation_Short_Range_Public_Area'
                DF_Temp_2.iloc[25, 37] = DF_Temp_3['Inf_ctb_inh_sho_com'].sum() / No_Temp_3
                DF_Temp_2.iloc[26, 36] = 'Infection_Contribution_Before_Quarantine_Direct_Spray_Short_Range_Staterooms'
                DF_Temp_2.iloc[26, 37] = DF_Temp_3['Inf_ctb_dir_spr_cab'].sum() / No_Temp_3
                DF_Temp_2.iloc[27, 36] = 'Infection_Contribution_Before_Quarantine_Direct_Spray_Short_Range_Public_Area'
                DF_Temp_2.iloc[27, 37] = DF_Temp_3['Inf_ctb_dir_spr_com'].sum() / No_Temp_3
                DF_Temp_2.iloc[28, 36] = 'Infection_Contribution_Before_Quarantine_Fomite_Staterooms'
                DF_Temp_2.iloc[28, 37] = DF_Temp_3['Inf_ctb_fom_cab'].sum() / No_Temp_3
                DF_Temp_2.iloc[29, 36] = 'Infection_Contribution_Before_Quarantine_Fomite_Public_Area'
                DF_Temp_2.iloc[29, 37] = DF_Temp_3['Inf_ctb_fom_com'].sum() / No_Temp_3
                DF_Temp_2.iloc[30, 36] = 'Infection_Contribution_After_Quarantine_Inhalation_Long_Range_Staterooms'
                DF_Temp_2.iloc[30, 37] = (DF_Temp_2['Inf_ctb_inh_lon_cab'].sum() - DF_Temp_3['Inf_ctb_inh_lon_cab'].sum()) / (1 - No_Temp_3)
                DF_Temp_2.iloc[31, 36] = 'Infection_Contribution_After_Quarantine_Inhalation_Long_Range_Public_Area'
                DF_Temp_2.iloc[31, 37] = (DF_Temp_2['Inf_ctb_inh_lon_com'].sum() - DF_Temp_3['Inf_ctb_inh_lon_com'].sum()) / (1 - No_Temp_3)
                DF_Temp_2.iloc[32, 36] = 'Infection_Contribution_After_Quarantine_Inhalation_Short_Range_Staterooms'
                DF_Temp_2.iloc[32, 37] = (DF_Temp_2['Inf_ctb_inh_sho_cab'].sum() - DF_Temp_3['Inf_ctb_inh_sho_cab'].sum()) / (1 - No_Temp_3)
                DF_Temp_2.iloc[33, 36] = 'Infection_Contribution_After_Quarantine_Inhalation_Short_Range_Public_Area'
                DF_Temp_2.iloc[33, 37] = (DF_Temp_2['Inf_ctb_inh_sho_com'].sum() - DF_Temp_3['Inf_ctb_inh_sho_com'].sum()) / (1 - No_Temp_3)
                DF_Temp_2.iloc[34, 36] = 'Infection_Contribution_After_Quarantine_Direct_Spray_Short_Range_Staterooms'
                DF_Temp_2.iloc[34, 37] = (DF_Temp_2['Inf_ctb_dir_spr_cab'].sum() - DF_Temp_3['Inf_ctb_dir_spr_cab'].sum()) / (1 - No_Temp_3)
                DF_Temp_2.iloc[35, 36] = 'Infection_Contribution_After_Quarantine_Direct_Spray_Short_Range_Public_Area'
                DF_Temp_2.iloc[35, 37] = (DF_Temp_2['Inf_ctb_dir_spr_com'].sum() - DF_Temp_3['Inf_ctb_dir_spr_com'].sum()) / (1 - No_Temp_3)
                DF_Temp_2.iloc[36, 36] = 'Infection_Contribution_After_Quarantine_Fomite_Staterooms'
                DF_Temp_2.iloc[36, 37] = (DF_Temp_2['Inf_ctb_fom_cab'].sum() - DF_Temp_3['Inf_ctb_fom_cab'].sum()) / (1 - No_Temp_3)
                DF_Temp_2.iloc[37, 36] = 'Infection_Contribution_After_Quarantine_Fomite_Public_Area'
                DF_Temp_2.iloc[37, 37] = (DF_Temp_2['Inf_ctb_fom_com'].sum() - DF_Temp_3['Inf_ctb_fom_com'].sum()) / (1 - No_Temp_3)

                DF_Temp_2.to_excel(writer_acc, sheet_name='R0=' + STR_R0 + '_ID=' + STR_ID + '_Eff=' + STR_Eff)

            DF_Temp_2.to_excel(writer, sheet_name='R0=' + STR_R0 + '_ID=' + STR_ID + '_Eff=' + STR_Eff)

            y = 0
            for y in range(38):
                DF_Temp_0.iloc[No_Temp_0, y] = DF_Temp_2.iloc[y, 37]

            No_Temp_0 = No_Temp_0 + 1


writer.save()
writer_acc.save()

DF_Result_Summary = pd.read_excel(
    r'C:\Users\paa009\Dropbox (Harvard University)\COVID-19_Harvard-IIT\Calculation\COVID19_Results_Summary.xlsx',
    sheet_name='Sheet1')

DF_Result_Summary = DF_Result_Summary.drop(DF_Result_Summary.columns[0], axis=1)
DF_Result_Summary = DF_Result_Summary.append(DF_Temp_0)

writer_sum = pd.ExcelWriter(
    r'C:\Users\paa009\Dropbox (Harvard University)\COVID-19_Harvard-IIT\Calculation\COVID19_Results_Summary',
    engine='xlsxwriter')
DF_Result_Summary.to_excel(writer_sum, sheet_name='Sheet1')
writer_sum.save()

print(No_R2)

end = time.time()
print('---------')
print('GOOD JOB!')
print(end-start)
